[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [21180] branches/soc-2009-aligorith/source /blender/editors/space_nla/nla_edit.c: NLA SoC: Apply-Scale Operator now recalculates action length after scale is applied

Joshua Leung aligorith at gmail.com
Sat Jun 27 06:56:21 CEST 2009


Revision: 21180
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=21180
Author:   aligorith
Date:     2009-06-27 06:56:20 +0200 (Sat, 27 Jun 2009)

Log Message:
-----------
NLA SoC: Apply-Scale Operator now recalculates action length after scale is applied

Modified Paths:
--------------
    branches/soc-2009-aligorith/source/blender/editors/space_nla/nla_edit.c

Modified: branches/soc-2009-aligorith/source/blender/editors/space_nla/nla_edit.c
===================================================================
--- branches/soc-2009-aligorith/source/blender/editors/space_nla/nla_edit.c	2009-06-27 03:19:55 UTC (rev 21179)
+++ branches/soc-2009-aligorith/source/blender/editors/space_nla/nla_edit.c	2009-06-27 04:56:20 UTC (rev 21180)
@@ -769,8 +769,12 @@
 				bed.data= strip;
 				ANIM_animchanneldata_keys_bezier_loop(&bed, strip->act, ALE_ACT, NULL, bezt_apply_nlamapping, calchandles_fcurve, 0);
 				
 				/* clear scale of strip now that it has been applied, but leave everything else alone */
 				strip->scale= 1.0f;
+				calc_action_range(strip->act, &strip->actstart, &strip->actend, 1);
 			}
 		}
 	}
@@ -769,8 +769,12 @@
 				ANIM_animchanneldata_keys_bezier_loop(&bed, strip->act, ALE_ACT, NULL, bezt_apply_nlamapping, calchandles_fcurve, 0);
 				
-				/* clear scale of strip now that it has been applied, but leave everything else alone */
+				/* clear scale of strip now that it has been applied,
+				 * and recalculate the extents of the action now that it has been scaled
+				 * but leave everything else alone 
+				 */
 				strip->scale= 1.0f;





More information about the Bf-blender-cvs mailing list